.. libgetar documentation master file, created by
   sphinx-quickstart on Tue Dec 16 09:20:17 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

====================================
Welcome to libgetar's documentation!
====================================

Introduction
============

libgetar is a library to read and write GEneric Trajectory ARchives, a
binary data format designed for efficient, extensible storage of
trajectory data.

Contents:

.. toctree::
   :maxdepth: 2

   inst
   gtar
   backends
   py/gtar
   cpp/gtar
   issues

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
